[![CircleCI](https://circleci.com/gh/18F/django-uswds-forms.svg?style=svg)](https://circleci.com/gh/18F/django-uswds-forms)

This package provides [Django Forms][django-forms] integration with the
[U.S. Web Design Standards][uswds].

This is a work-in-progress and may eventually be subsumed into
[django-designstandards][] depending on what's best for everyone.

For documentation, please visit [django-uswds-forms.readthedocs.io][].

[django-designstandards]: https://github.com/department-of-veterans-affairs/django-designstandards
[uswds]: https://standards.usa.gov/
[django-uswds-forms.readthedocs.io]: http://django-uswds-forms.readthedocs.io/en/latest/
[django-forms]: https://docs.djangoproject.com/en/1.11/topics/forms/#the-django-form-class
